@@ -1,7 +1,7 @@
 /*
  *  UFTP - UDP based FTP with multicast
  *
- *  Copyright (C) 2001-2016   Dennis A. Bush, Jr.   bush@tcnj.edu
+ *  Copyright (C) 2001-2017   Dennis A. Bush, Jr.   bush@tcnj.edu
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -836,8 +836,7 @@ void clear_path(const char *path, struct group_list_t *group)
         struct _finddatai64_t finfo;
         char dirglob[MAXPATHNAME];
 
-        snprintf(dirglob, sizeof(dirglob), "%s%c*", path,
-                 PATH_SEP, group->group_id, PATH_SEP);
+        snprintf(dirglob, sizeof(dirglob), "%s%c*", path, PATH_SEP);
         if ((ffhandle = _findfirsti64(dirglob, &finfo)) == -1) {
             gsyserror(group, "Failed to open directory %s", path);
             return;
