@@ -1,7 +1,7 @@
 /*
  *  UFTP - UDP based FTP with multicast
  *
- *  Copyright (C) 2001-2016   Dennis A. Bush, Jr.   bush@tcnj.edu
+ *  Copyright (C) 2001-2017   Dennis A. Bush, Jr.   bush@tcnj.edu
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -31,6 +31,8 @@
 #ifndef _UFTP_H
 #define _UFTP_H
 
+#include <stdint.h>
+
 #ifdef WINDOWS
 
 // same as passing /D _CRT_SECURE_NO_WARNINGS to cl
@@ -39,15 +41,6 @@
 #include <windows.h>
 #include <process.h>
 
-typedef unsigned __int8 uint8_t;
-typedef __int8 int8_t;
-typedef unsigned __int16 uint16_t;
-typedef __int16 int16_t;
-typedef unsigned __int32 uint32_t;
-typedef __int32 int32_t;
-typedef unsigned __int64 uint64_t;
-typedef __int64 int64_t;
-
 #define open(name, ...) _open(name, __VA_ARGS__)
 #define read(fd, buf, count) _read(fd, buf, count)
 #define close(fd) _close(fd)
@@ -74,7 +67,6 @@ typedef struct _utimbuf utim_buf;
 #define S_ISDIR(mode)   (((mode) & S_IFMT) == S_IFDIR)
 #define S_ISREG(mode)   (((mode) & S_IFMT) == S_IFREG)
 #define lseek_func(fd, offset, whence) _lseeki64(fd, offset, whence)
-#define snprintf(buf, cnt, ...) _snprintf(buf, cnt, __VA_ARGS__)
 #define strtok_r(str, delim, save) strtok_s(str, delim, save)
 
 typedef int socklen_t;
@@ -87,7 +79,7 @@ typedef HANDLE mux_t;
 #define mux_lock(mux) ((WaitForSingleObject(mux,INFINITE)!=WAIT_FAILED)?0:-1)
 #define mux_unlock(mux) ((ReleaseMutex(mux)!=0)?0:-1)
 
-typedef unsigned long thread_t;
+typedef uintptr_t thread_t;
 #define start_thread(id,func,arg) (((id=_beginthread(func,0,arg))!=-1)?0:-1)
 #define end_thread() _endthread()
 #define thread_id() GetCurrentThreadId()
@@ -98,7 +90,6 @@ typedef unsigned long thread_t;
 
 #else  // if WINDOWS
 
-#include <inttypes.h>
 #include <pthread.h>
 
 
@@ -150,7 +141,7 @@ typedef pthread_t thread_t;
 
 #endif // if WINDOWS
 
-#define VERSIONSTR "UFTP version 4.9.2  Copyright (C) 2001-2016  Dennis A. Bush"
+#define VERSIONSTR "UFTP version 4.9.3  Copyright (C) 2001-2017  Dennis A. Bush"
 #define UFTP_VER_NUM 0x40
 
 #define ANNOUNCE      1
